@@ -66,8 +66,10 @@ class ReportSonar:
         
         if args["use_secrets_manager"] == "true": 
             secret = self.secrets_manager_gateway.get_secret(config_tool)
+            secret_tool = secret
         else: 
             secret = args
+            secret_tool = None
 
         report_config_tool = self.devops_platform_gateway.get_remote_config(
             args["remote_config_repo"],
@@ -87,7 +89,7 @@ class ReportSonar:
             scan_type = "SONARQUBE",
             input_core = input_core,
             dict_args = args,
-            secret_tool = self.secrets_manager_gateway,
+            secret_tool = secret_tool,
             config_tool = config_tool,
             source_code_management_uri = source_code_management_uri,
             base_compact_remote_config_url = compact_remote_config_url,
@@ -104,7 +106,7 @@ class ReportSonar:
                 findings = self.vulnerability_management_gateway.get_all(
                     service=project_key,
                     dict_args=args,
-                    secret_tool=self.secrets_manager_gateway,
+                    secret_tool=secret_tool,
                     config_tool=config_tool
                 )[0]
                 filtered_findings = self.sonar_gateway.filter_by_sonarqube_tag(findings)
