@@ -7,6 +7,7 @@ from devsecops_engine_tools.engine_utilities.utils.printers import (
 from devsecops_engine_tools.engine_core.src.domain.usecases.metrics_manager import (
     MetricsManager,
 )
+import re
 from devsecops_engine_tools.engine_utilities.utils.logger_info import MyLogger
 from devsecops_engine_tools.engine_utilities import settings
 
@@ -16,9 +17,17 @@ def init_report_sonar(vulnerability_management_gateway, secrets_manager_gateway,
     config_tool = devops_platform_gateway.get_remote_config(
         args["remote_config_repo"], "/engine_core/ConfigTool.json"
     )
+    report_config_tool = devops_platform_gateway.get_remote_config(
+        args["remote_config_repo"], "/report_sonar/ConfigTool.json"
+    )
     Printers.print_logo_tool(config_tool["BANNER"])
 
-    if config_tool["REPORT_SONAR"]["ENABLED"] == "true":
+    pipeline_name = devops_platform_gateway.get_variable("pipeline_name")
+    branch = devops_platform_gateway.get_variable("branch_name")
+    is_valid_pipeline = not re.match(report_config_tool["IGNORE_SEARCH_PATTERN"], pipeline_name, re.IGNORECASE)
+    is_valid_branch = branch in report_config_tool["TARGET_BRANCHES"]
+
+    if config_tool["REPORT_SONAR"]["ENABLED"] == "true" and is_valid_pipeline and is_valid_branch:
         input_core = ReportSonar(
             vulnerability_management_gateway,
             secrets_manager_gateway, 
